@@ -11,20 +11,20 @@ from fastapi.encoders import jsonable_encoder
 from fastapi.routing import APIRoute
 from starlette.datastructures import CommaSeparatedStrings
 
-from .backend import DEFAULT_LOCK_TIMEOUT, BaseCacheBackend
+from .backend import DEFAULT_LOCK_TIMEOUT, EX, BaseCacheBackend
 from .redis import RedisCacheBackend
 
 MIN_AUTOREFRESH_RATE = 60
-MIN_CACHE_EXPIRE = 30
 
 
 class CachedResponse(Exception):
-    def __init__(self, response: Response) -> None:
-        self.response = response
+    def __init__(self, *args, content: str, ttl: int) -> None:  # noqa:WPS110
+        self.content = content  # noqa:WPS110
+        self.ttl = ttl
 
     def __repr__(self) -> str:
         class_name = self.__class__.__name__
-        return f"{class_name}(status_code={self.response.status_code!r})"  # noqa: WPS237
+        return f"{class_name}(ttl={self.ttl!r})"  # noqa: WPS237
 
 
 class Cache:
@@ -34,7 +34,7 @@ class Cache:
 
     def __init__(
         self,
-        exp: int,
+        exp: EX,
         auto_refresh: bool = False,
         cache_control: bool = False,
         namespace: Optional[str] = None,
@@ -42,7 +42,7 @@ class Cache:
     ):
         """Atomic cache manager.
         Args:
-            exp (int): Cache TTL. Zero(0) mean infinite.
+            exp (int): Cache expire. None mean infinite.
             auto_refresh (bool, optional): Refresh cache in background. Defaults to False.
             cache_control (bool, optional): React based on cache Cache-Control from request's header. Defaults to False.
             namespace (Optional[str], optional): Cache storage namespace. Defaults is the route path.
@@ -58,8 +58,9 @@ class Cache:
             await asyncio.sleep(10)  # Do some heavy work for 10 sec, see `lock_timeout`
             return cache.set(response, cache_id=cache_id)
         """
+        assert not auto_refresh or exp is not None, "Autorefresh doesn't support inifinite rate expire"
         assert not auto_refresh or exp >= MIN_AUTOREFRESH_RATE, f"Min autorefresh rate is {MIN_AUTOREFRESH_RATE}"
-        assert exp == 0 or exp >= MIN_CACHE_EXPIRE, f"Min cache expire is {MIN_CACHE_EXPIRE} or 0 for permanent"
+        assert exp is None or exp >= lock_timeout, f"ValueError: {lock_timeout=} must be less than {exp=}"
         self.auto_refresh = auto_refresh
         self._expire = exp
         self.namespace = namespace
@@ -145,16 +146,7 @@ class Cache:
             lockspace=lockspace,
         )
         if cached_content is not None:
-            response = Response(media_type="application/json")
-            if_none_match = self._request.headers.get("if-none-match")
-            response.headers["Cache-Control"] = f"max-age={ttl}"
-            etag = f"W/{hashsum(cached_content)}"
-            if if_none_match == etag:
-                response.status_code = 304
-            else:
-                response.headers["ETag"] = etag
-                response.body = cached_content
-            raise CachedResponse(response)
+            raise CachedResponse(content=cached_content, ttl=ttl)
 
     def schedule_autorefresh(self):
         if self.auto_refresh:
@@ -210,8 +202,18 @@ class Cache:
         self._autorefresh_task = asyncio.ensure_future(self._autorefresh())
 
 
-def cached_response_handler(_: Request, exc: CachedResponse) -> Response:
-    return exc.response
+def cached_response_handler(request: Request, exc: CachedResponse) -> Response:
+    if_none_match = request.headers.get("if-none-match")
+    etag = f"W/{hashsum('exc.content')}"
+    if if_none_match == etag:
+        response = Response(status_code=304, headers={"Cache-Control": f"max-age={exc.ttl}"})  # noqa:WPS432
+    else:
+        response = Response(
+            media_type="application/json",
+            content=exc.content,
+            headers={"Cache-Control": f"max-age={exc.ttl}", "ETag": etag},
+        )
+    return response
 
 
 def hashsum(obj: str) -> str:  # noqa: WPS110
